/**********************************************************************

	Command:  SAVEOPT -- Save Drawing Option Setup Dialog

	Programmed by Kang, Hsin-Min.
	Release at Jun 24, 1997
	Revised at Jul 03, 1997 For TAG file suppression option
	Revised at Oct 19, 1997 For Encrypted WRK file option & Help button
	Revised at Apr 22, 1998 Include Japenese Text in SJIS codes
	Revised at Aug 05, 1998 Modify Japenese Messages.

	Copyright (c) 1997, 1998 TCAM Development House, Taipei
	All rights Reserved.

	Status: Standard Command, with full support.

	The following options are setup by this commands:

	AutoSave features,
	Preview Options,
	Save Backup features,
	Save Encrypted WRK file,
	DWG file versions, etc.

***********************************************************************/
int	IsWin;
int	nSupport=identify("wnd_resize");
// Certain functions are supported only in Windows version and after
// wnd_resize(), so checking this will help to identify these supports.
//
//	Copy System variables to local variable for editing
//
char	savefile[80]=@savefile;
int	savebackup=@savebackup;
int	savetime=@savetime;
int	previewopt=@previewopt;
int	autosave=@autosave;
int	dwgversion=@dwgversion;
int	encrypt=@encrypt;
//
//	Tag file suppression is supported if wnd_group() is also supported.
//
int	HasTagSup=identify("wnd_group");
//
//	Definition for preview option
//
#define PVSLIDE 	0x0001
#define PVWBLOCK	0x2000
#define PVEMBED 	0x4000
#define PVQUERY 	0x8000

char	szTimesTable[][6]={	// Oblique Angles
	"<N/A>","30","60","90","120","150","180"
};
char	szCntsTable[][6]={    // Character Space
	"<N/A>","50","100","150","200","300","500"
};

int	nMain[6]={6,20,10,72,0x3270,0x8000};
int	widMain;	// Main Dialog Window ID
int	nTatrb=0x2f0;
int	nSatrb=0x270;
int	bSaveFile;
int	bSaveTime;
int	bSaveCnt;
int	bpSlide;
int	bpWblock;
int	bpEmbed;
int	bpQuery;
int	bR10;
int	bR12;
int	bNoTag;
int	bBackup;
int	bEncrypt;
int	bOK;
int	bCancel;
int	bHelp=0;

char	szText[22][40]; // Our display text buffer, see SetMsgText()
			// at the end of this file

// Macro to update variable with Undo consideration.
#define savevar(name)	if (name!=@name) { set_undo("name"); @name=name;}

COMMAND SaveOpt()
{
	IsWin = 1;
	switch(1) {  // Test if we are in TwinCAD ...
	  case !identify("os_type"):
	  case (os_type()<0):	// Must be in DOS version!
		IsWin = 0;
		break;
	}
	SetMsgText();
	if ( DoSaveOpt() ) {	// Ok, update these variables
		savevar(savefile);
		savevar(savebackup);
		savevar(autosave);
		savevar(savetime);
		savevar(dwgversion);
		savevar(previewopt);
		savevar(encrypt);
	}
}

int	DoSaveOpt()
{
	int	nBtn;
	int	which;

	OpenDialog();
	UpdateDialog();
	for(;;) {
		nBtn = wnd_gbtn(0);
		switch(nBtn) {
		  case -3:
		  case -2:
		  case -1:
		  case	0:
			CloseDialog();
			return 0;
		  case bSaveFile:
			savefile = getfile(savefile,"SAV",0x81,
				szText[0]/*"Enter Automatic Save Filename"*/);
			wnd_ftext(bSaveFile,prints("%-42s",(savefile!="")?savefile:
				szText[1]/*"[Original Drawing File]"*/),nTatrb);
			continue;
		  case bSaveTime:
			savetime = wnd_fgetd(bSaveTime,8,0x4e,savetime,nMain[0]+6,nMain[2]+16);
			wnd_ftext(bSaveTime,savetime?prints("%8d",savetime):
				     prints("%^8s","<N/A>"),nTatrb);
			continue;
		  case bSaveTime+1:
			if ( (which=wnd_fgeto(bSaveTime,szTimesTable,0xf0,7,-1)) < 0 )
				continue;
			savetime = 0;
			if ( which )
				savetime = eval(szTimesTable[which]);
			wnd_ftext(bSaveTime,savetime?prints("%8d",savetime):
				     prints("%^8s","<N/A>"),nTatrb);
			continue;
		  case bSaveCnt:
			autosave = wnd_fgetd(bSaveCnt,8,0x4e,autosave,nMain[0]+6,nMain[2]+38);
			wnd_ftext(bSaveCnt,autosave?prints("%8d",autosave):
				     prints("%^8s","<N/A>"),nTatrb);
			continue;
		  case bSaveCnt+1:
			if ( (which=wnd_fgeto(bSaveCnt,szCntsTable,0xf0,7,-1)) < 0 )
				continue;
			autosave = 0;
			if ( which )
				autosave = eval(szCntsTable[which]);
			wnd_ftext(bSaveCnt,autosave?prints("%8d",autosave):
				     prints("%^8s","<N/A>"),nTatrb);
			continue;
		  case bpSlide:
			previewopt ^= PVSLIDE;
			wnd_fmark(bpSlide,0,(previewopt&PVSLIDE)?0x8000:0x80ff);
			if ( identify("wnd_state") ) {
			    if ( previewopt&PVSLIDE ) {
				wnd_state(bpEmbed,1,0);
				wnd_state(bpWblock,1,0);
				wnd_state(bpQuery,1,0);
			    }
			    else {
				wnd_state(bpEmbed,1,1);
				wnd_state(bpWblock,1,1);
				wnd_state(bpQuery,1,1);
			    }
			}
			continue;
		  case bpWblock:
			previewopt ^= PVWBLOCK;
			wnd_fmark(bpWblock,0,(previewopt&PVWBLOCK)?0x8000:0x80ff);
			continue;
		  case bpEmbed:
			previewopt ^= PVEMBED;
			wnd_fmark(bpEmbed,0,(previewopt&PVEMBED)?0x8000:0x80ff);
			continue;
		  case bpQuery:
			previewopt ^= PVQUERY;
			wnd_fmark(bpQuery,0,(previewopt&PVQUERY)?0x8000:0x80ff);
			continue;
		  case bR10:
		  case bR12:
			if ( HasTagSup ) {
			    dwgversion &= 0xfff0;
			    dwgversion |= (nBtn==bR12)?1:0;
			}
			else
			    dwgversion = (nBtn==bR12)?1:0;
			wnd_fmark(bR10,1,(!(dwgversion&1))?0x8000:0x80ff);
			wnd_fmark(bR12,1,(dwgversion&1)?0x8000:0x80ff);
			continue;
		  case bNoTag:
			if ( !HasTagSup ) {
			    beep();    // For DOS version.
			    continue;
			}
			dwgversion ^= 0x8000;
			wnd_fmark(bNoTag,0,(dwgversion&0x8000)?0x8000:0x80ff);
			continue;
		  case bBackup:
			savebackup = !savebackup;
			wnd_fmark(bBackup,0,(savebackup)?0x8000:0x80ff);
			continue;
		  case bEncrypt:
			encrypt = !encrypt;
			wnd_fmark(bEncrypt,0,(encrypt)?0x8000:0x80ff);
			continue;
		  case bHelp:
			show_help("","SAVEOPT");
			continue;
		  case bCancel:
			CloseDialog();
			return 0;
		  case bOK:
			CloseDialog();
			return 1;
		}
	}
}
//
//	OpenDialog() -- Open main dialog window, create screen items.
//
void	OpenDialog()
{
	int	rBase, cBase, col;
	int	rInc=0x0801;
	widMain = wndopen(nMain,szText[2]/*"Save Option Setup Dialog"*/,0x3f1f,nMain[5]);
	WndGroup(0x0800,2,59,3,szText[3]/*"Automatic Save"*/,nSatrb);
	rBase = 0x0800+0x0501;
	cBase = 4;
	bSaveFile = WndEntry(rBase+rInc*0,cBase,szText[4]/*" Save File: "*/,0x12b,0);
	bSaveTime = WndEntry(rBase+rInc*1,cBase,szText[5]/*"Save every: "*/,0x108,1);
	col = cBase + len(szText[5]/*"Save every: "*/)+11;
	bSaveCnt  = WndEntry(rBase+rInc*1,col,szText[6]/*"Minutes, or "*/,0x108,1);
	wnd_rloct(0,1);
	put3Dstr(szText[7]/*"Commands"*/,nSatrb);

	WndGroup(0x0405,2,24,6,szText[8]/*"Preview Options"*/,nSatrb);
	rBase = 0x0405+0x0501;
	cBase = 2;
	bpSlide = WndCheckBox(rBase+rInc*0,cBase,szText[9] /*"Save Preview Slide"*/,nSatrb);
	bpEmbed = WndCheckBox(rBase+rInc*1,cBase+2,szText[10]/*"Embed it in WRK file"*/,nSatrb);
	bpWblock= WndCheckBox(rBase+rInc*2,cBase+2,szText[11]/*"Save for WBLOCK"*/,nSatrb);
	bpQuery = WndCheckBox(rBase+rInc*3,cBase+2,szText[12]/*"Query before saving"*/,nSatrb);

	WndGroup(0x0405,28,21,3,szText[13]/*"DWG File Options"*/,nSatrb);
	rBase = 0x0405+0x0501;
	cBase = 29;
	bR10	= WndRadioBox(rBase+rInc*0,cBase,szText[14]/*"Save R10 Format"*/,nSatrb);
	bR12	= WndRadioBox(rBase+rInc*0,cBase+10,szText[15]/*"Save R12 Format"*/,nSatrb);
	bNoTag	= WndCheckBox(rBase+rInc*1,cBase,szText[19]/*"Suppress TAG File"*/,nSatrb);

	rBase += rInc*2;
	rBase += 0x800;
	bBackup = WndCheckBox(rBase+rInc*0,cBase,szText[16]/*"Backup Original File"*/,nSatrb);
	bEncrypt= WndCheckBox(rBase+rInc*1,cBase,szText[21]/*"Save Encrypted WRK"*/,nSatrb);

	rBase = 0x0405+0x0001;
	cBase = 52;
	rInc = 0x0401;
	bOK	= WndButton(rBase+rInc*0,cBase,0x108,szText[17]/*"   OK   "*/);
	bCancel = WndButton(rBase+rInc*2,cBase,0x108,szText[18]/*" Cancel "*/);
    if ( IsWin )
	bHelp	= WndButton(rBase+rInc*4,cBase,0x108,szText[20]/*"  Help  "*/);
}
//
void	UpdateDialog()
{
	wnd_ftext(bSaveFile,prints("%-42s",(savefile!="")?savefile:
		szText[1]/*"[Original Drawing File]"*/),nTatrb);
	wnd_ftext(bSaveTime,savetime?prints("%8d",savetime):
				     prints("%^8s","<N/A>"),nTatrb);
	wnd_ftext(bSaveCnt,autosave?prints("%8d",autosave):
				     prints("%^8s","<N/A>"),nTatrb);

	wnd_fmark(bpSlide,0,(previewopt&PVSLIDE)?0x8000:0x80ff);
	wnd_fmark(bpEmbed,0,(previewopt&PVEMBED)?0x8000:0x80ff);
	wnd_fmark(bpWblock,0,(previewopt&PVWBLOCK)?0x8000:0x80ff);
	wnd_fmark(bpQuery,0,(previewopt&PVQUERY)?0x8000:0x80ff);
	wnd_fmark(bBackup,0,(savebackup)?0x8000:0x80ff);
	wnd_fmark(bEncrypt,0,(encrypt)?0x8000:0x80ff);
	wnd_fmark(bR10,1,(!(dwgversion&1))?0x8000:0x80ff);
	wnd_fmark(bR12,1,(dwgversion&1)?0x8000:0x80ff);
	if ( !HasTagSup ) {
	    if ( identify("wnd_state") )
		wnd_state(bNoTag,1,1);	// Disable if old version
	}
	wnd_fmark(bNoTag,1,(dwgversion&0x8000)?0x8000:0x80ff);
	if ( identify("wnd_state") ) {
	    if ( previewopt&PVSLIDE ) {
		wnd_state(bpEmbed,1,0);
		wnd_state(bpWblock,1,0);
		wnd_state(bpQuery,1,0);
	    }
	    else {
		wnd_state(bpEmbed,1,1);
		wnd_state(bpWblock,1,1);
		wnd_state(bpQuery,1,1);
	    }
	}
}
//
//	CloseDialog() -- Close the main dialog window, save window attribute
//
void	CloseDialog()
{
	wndclose();
}
//
//	WndGroup() -- Create Groupping window effect
//
void	WndGroup(int r,int c,int width, int height, char text[], int color)
{
	wnd_loct(r,c);
	wnd_rloct(height,0);
	if ( IsWin )
		wnd_field(0,0x277,(height<<8)|width);
	else
		wnd_field(0,0x270,(height<<8)|width);
	wnd_itemno(1,-1);
	wnd_rloct(-height,2);
	if ( !IsWin )
		wnd_rloct(0xfc00,0);
	put3Dstr(text,color);
	wnd_loct(r,c);	      // Reset row offset, fix DOS version bug
}
//
//	put3Dstr() -- Drawing 3D text
//
void	put3Dstr(char str[],int atrb)
{
	int	nLen;
	if ( nSupport ) {
		wnd_puts(str,atrb|0x300);
		return;
	}
	nLen=len(str);
	if ( nLen ) {
		wnd_rloct(0x100,IsWin?0x100:0);
		wnd_puts(str,(atrb^0x0f));
		wnd_rloct(0xff00,-nLen);
		wnd_puts(str,(atrb&0xff0f)|0x8000);
	}
}
//
//	WndCheckBox() -- Create window check box
//
int	WndCheckBox(int r,int c,char text[],int atrb)
{
	int	bID;
	if ( nSupport )
		return wnd_rcbox(r,c,text,0);
	wnd_loct(r,c);
	bID = wnd_field(1,0x1f0,0x102);
	wnd_rloct(0,2);
	if ( IsWin )  atrb |= 0x800;
	wnd_puts(text,atrb);
	return bID;
}
//
//	WndRadioBox() -- Create window radio box
//
int	WndRadioBox(int r,int c,char text[],int atrb)
{
	int	bID;
	if ( nSupport )
		return wnd_rcbox(r,c,text,0x8000);
	wnd_loct(r,c);
	bID = wnd_field(1,0x1f0,0x102);
	wnd_rloct(0,2);
	if ( IsWin ) atrb |= 0x800;
	wnd_puts(text,atrb);
	wnd_fmark(bID,1,IsWin?1:0x8000);     // Force to change state
	wnd_fmark(bID,1,IsWin?0:0x80ff);
	return bID;
}
//
int	WndButton(int r,int c, int bsize, char text[])
{
	int	i;
	if ( nSupport ) 	// Having direct support ?
		return wnd_button(r,c,bsize,0x1277,text);
	wnd_loct(r,c);
	i = wnd_field(0,IsWin?0x1277:0x370,bsize);
	wnd_puts(text,0x270);
	return i;
}
//
#define OBM_COMBO	"#32738"
int	WndEntry(int row, int col, char str[],int fsize,int combo)
{
	int	bID;

	wnd_loct(row,col);
	put3Dstr(str,nSatrb);
	bID = wnd_field(0,IsWin?(0x1f1):0x21f1,fsize);
	if ( combo ) {
		wnd_rloct(0xfe00,0x0600|(fsize&0xff));
		if ( IsWin) wnd_runit(12);
		if ( identify("cb_empty") ) {   // Supported only after this version
		     wnd_icon(1,0xA77,0x101,OBM_COMBO);
		     wnd_runit(-1);
		     wnd_rloct(0x0200,0x0002);	// locate back
		}
		else {
		     wnd_field(0,IsWin?0x277:0x370,0x101);
		     wnd_runit(IsWin?-1:16);
		     wnd_ftext(bID+1,"",IsWin?0x277:0x270);
		     wnd_rloct(0x0200,0x0201);	// locate back
		}
	}
	return bID;
}

char	szAsciiText[][40]={	    // Default English Display Text
/*  0 */   "Enter Automatic Save Filename",
/*  1 */   "[Original Drawing File]",
/*  2 */   "Save Option Setup Dialog",
/*  3 */   "Automatic Save",
/*  4 */   " Save File: ",
/*  5 */   "Save every: ",
/*  6 */   "Minutes, or ",
/*  7 */   "Commands",
/*  8 */   "Preview Options",
/*  9 */   "Save Preview Slide",
/* 10 */   "Embed it in WRK file",
/* 11 */   "Save for WBLOCK",
/* 12 */   "Query before saving",
/* 13 */   "Save DWG File",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "Backup Original File",
/* 17 */   "&OK",
/* 18 */   "&Cancel",
/* 19 */   "Suppress TAG File",
/* 20 */   "&Help",
/* 21 */   "Save Encrypted WRK",
};

char	szBig5Text[][40]={	   // Default Chinese Big-5 Display Text
/*  0 */   "Ыw۰ʦsɳƥΪȮɦW",
/*  1 */   "esɦܥثeϥιɤf",
/*  2 */   "s    \\  ] w",
/*  3 */   "۰ʦs",
/*  4 */   "ȦsɦW: ",
/*  5 */   "۰ʨCj: ",
/*  6 */   ",  ",
/*  7 */   "Os",
/*  8 */   "ɹw]w",
/*  9 */   "sXɹwۿO",
/* 10 */   "rJWRK ɤ",
/* 11 */   "tWBLOCKҦs",
/* 12 */   "sɮɦA",
/* 13 */   "sDWGɳ]w",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "sɮ, ɳƥ",
/* 17 */   "Tw[&O]",
/* 18 */   "[&C]",
/* 19 */   "TAG",
/* 20 */   "[&H]",
/* 21 */   "s[KO@WRK ",
};

char	szGB2312Text[][40]={	// Default Chinese GB2312 Display Text
/*  0 */   "ָԶ浵õʱ",
/*  1 */   "ֱӴ浵Ŀǰʹͼڣ",
/*  2 */   "  ѡ     ",
/*  3 */   "Զ浵",
/*  4 */   "ݴ浵: ",
/*  5 */   "Զÿ: ",
/*  6 */   ",  ",
/*  7 */   "ָ浵",
/*  8 */   "ͼԤ趨",
/*  9 */   "ͼԤӻõƬ",
/* 10 */   "WRK ͼ",
/* 11 */   "WBLOCK֮ͼ",
/* 12 */   "浵ʱ",
/* 13 */   "DWG趨",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "浵ʱ, ԭͼ",
/* 17 */   "ȷ[&O]",
/* 18 */   "ȡ[&C]",
/* 19 */   "TAG",
/* 20 */   "˵[&H]",
/* 21 */   "ܱWRK ",
};
//
//	The following Japenese messages are translated by _____________.
//
char	szSJISText[][40]={    // Default Japenese SJIS Display Text
/*  0 */   "ۑ̃t@C͂ĉ",
/*  1 */   "ۑt@C",
/*  2 */   "ۑ̏ڍאݒ",
/*  3 */   "ۑ",
/*  4 */   "ۑt@C: ",
/*  5 */   "sԊu: ",
/*  6 */   "A܂ ",
/*  7 */   "R}h",
/*  8 */   "ޭ̐ݒ",
/*  9 */   "ײޭ̕ۑ",
/* 10 */   "ҰނWRĶقɔf",
/* 11 */   "WBLOCK̕ۑ",
/* 12 */   "ۑOɊmF",
/* 13 */   "DWGt@C̕ۑ",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "̧قޯ",
/* 17 */   "&OK",
/* 18 */   "ݾ[&C]",
/* 19 */   "TAG ̧ق폜",
/* 20 */   "[&H]",
/* 21 */   "߽ܰސݒ",
};
//
//	The following Korean messages are translated by _____________.
//
char	szKoreanText[][40]={	// Default Korean Display Text
/*  0 */   "Enter Automatic Save Filename",
/*  1 */   "[Original Drawing File]",
/*  2 */   "Save Option Setup Dialog",
/*  3 */   "Automatic Save",
/*  4 */   " Save File: ",
/*  5 */   "Save every: ",
/*  6 */   "Minutes, or ",
/*  7 */   "Commands",
/*  8 */   "Preview Options",
/*  9 */   "Save Preview Slide",
/* 10 */   "Embed it in WRK file",
/* 11 */   "Save for WBLOCK",
/* 12 */   "Query before saving",
/* 13 */   "Save DWG File",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "Backup Original File",
/* 17 */   "&OK",
/* 18 */   "&Cancel",
/* 19 */   "Suppress TAG File",
/* 20 */   "&Help",
/* 21 */   "Save Encrypted WRK",
};

char	szDosAsciiText[][40]={	       // Default English Display Text
/*  0 */   "Enter Automatic Save Filename",
/*  1 */   "[Original Drawing File]",
/*  2 */   "Save Option Setup Dialog",
/*  3 */   "Automatic Save",
/*  4 */   " Save File: ",
/*  5 */   "Save every: ",
/*  6 */   "Minutes, or ",
/*  7 */   "Commands",
/*  8 */   "Preview Options",
/*  9 */   "Save Preview Slide",
/* 10 */   "Embed it in WRK file",
/* 11 */   "Save for WBLOCK",
/* 12 */   "Query before saving",
/* 13 */   "Save DWG File",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "Backup Original File",
/* 17 */   "   OK   ",
/* 18 */   " Cancel ",
/* 19 */   "Suppress TAG File",
/* 20 */   "  Help  ",
/* 21 */   "Save Encrypted WRK",
};
char	szDosBig5Text[][40]={	      // Default Chinese Big-5 Display Text
/*  0 */   "Ыw۰ʦsɳƥΪȮɦW",
/*  1 */   "esɦܥثeϥιɤf",
/*  2 */   "s    \\  ] w",
/*  3 */   "۰ʦs",
/*  4 */   "ȦsɦW: ",
/*  5 */   "۰ʨCj: ",
/*  6 */   ",  ",
/*  7 */   "Os",
/*  8 */   "ɹw]w",
/*  9 */   "sXɹwۿO",
/* 10 */   "rJWRK ɤ",
/* 11 */   "tWBLOCKҦs",
/* 12 */   "sɮɦA",
/* 13 */   "sDWGɳ]w",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "sɮ, ɳƥ",
/* 17 */   "  Tw  ",
/* 18 */   "    ",
/* 19 */   "TAG",
/* 20 */   "  Help  ",
/* 21 */   "s[KO@WRK ",
};

char	szDosGB2312Text[][40]={    // Default Chinese GB2312 Display Text
/*  0 */   "ָԶ浵õʱ",
/*  1 */   "ֱӴ浵Ŀǰʹͼڣ",
/*  2 */   "  ѡ     ",
/*  3 */   "Զ浵",
/*  4 */   "ݴ浵: ",
/*  5 */   "Զÿ: ",
/*  6 */   ",  ",
/*  7 */   "ָ浵",
/*  8 */   "ͼԤ趨",
/*  9 */   "ͼԤӻõƬ",
/* 10 */   "WRK ͼ",
/* 11 */   "WBLOCK֮ͼ",
/* 12 */   "浵ʱ",
/* 13 */   "DWG趨",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "浵ʱ, ԭͼ",
/* 17 */   "  ȷ  ",
/* 18 */   "  ȡ  ",
/* 19 */   "TAG",
/* 20 */   "  Help  ",
/* 21 */   "ܱWRK ",
};
//
//	The following Japenese messages are translated by _____________.
//
char	szDosSJISText[][40]={	 // Default Japenese SJIS Display Text
/*  0 */   "ۑ̧ٖ",
/*  1 */   "ۑt@C",
/*  2 */   "ۑ̏ڍאݒ",
/*  3 */   "ۑ",
/*  4 */   "ۑt@C: ",
/*  5 */   "ۑԊu: ",
/*  6 */   "A܂ ",
/*  7 */   "R}h",
/*  8 */   "ޭ̐ݒ",
/*  9 */   "ײޭ̕ۑ",
/* 10 */   "ҰނWRĶقɔf",
/* 11 */   "WBLOCK̕ۑ",
/* 12 */   "ۑOɊmF",
/* 13 */   "DWG t@C̕ۑ",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "̧قޯ",
/* 17 */   "   OK   ",
/* 18 */   "  ݾ ",
/* 19 */   "TAG ̧ق폜",
/* 20 */   "    ",
/* 21 */   "߽ܰސݒ",
};
//
//	The following Korean messages are translated by _____________.
//
char	szDosKoreanText[][40]={    // Default Korean Display Text
/*  0 */   "Enter Automatic Save Filename",
/*  1 */   "[Original Drawing File]",
/*  2 */   "Save Option Setup Dialog",
/*  3 */   "Automatic Save",
/*  4 */   " Save File: ",
/*  5 */   "Save every: ",
/*  6 */   "Minutes, or ",
/*  7 */   "Commands",
/*  8 */   "Preview Options",
/*  9 */   "Save Preview Slide",
/* 10 */   "Embed it in WRK file",
/* 11 */   "Save for WBLOCK",
/* 12 */   "Query before saving",
/* 13 */   "Save DWG File",
/* 14 */   "R10",
/* 15 */   "R12",
/* 16 */   "Backup Original File",
/* 17 */   "   OK   ",
/* 18 */   " Cancel ",
/* 19 */   "Suppress TAG File",
/* 20 */   "  Help  ",
/* 21 */   "Save Encrypted WRK",
};

#define BIG5		0x404
#define GB2312		0x804
#define SJIS		0x411
#define KOREAN		0x412
#define ASCII		0x409

#define TGBIG5		1
#define TGGB2312	2
#define TGSJIS		5
#define TGKOREAN	3

int	SetMsgText()
{
	char	szBuf[80];
	int	switched;

	IsWin = 1;
	switch(1) {  // Test if we are in TwinCAD ...
	  case !identify("os_type"):
	  case (os_type()<0):	// Must be in DOS version!
		IsWin = 0;
		break;
	}

	if ( IsWin ) {
	    szBuf = get_profile("General Setup","AlternateLanguage");
	    switched = 0;
	    if ( szBuf!="" )
		switched = eval(szBuf);
	    if ( switched ) {
		switch(os_language()) {
		  case BIG5:	setdata(szText,szBig5Text);	break;
		  case GB2312:	setdata(szText,szGB2312Text);	break;
		  case SJIS:	setdata(szText,szSJISText);	break;
		  case KOREAN:	setdata(szText,szKoreanText);	break;
		  default:	setdata(szText,szAsciiText);	break;
		}
	    }
	    else
		setdata(szText,szAsciiText);
	}
	else {	// Switched or not, depends on TGF type in DOS version
	    switch(@tgftype) {
	      case TGBIG5:    setdata(szText,szDosBig5Text);	 break;
	      case TGGB2312:  setdata(szText,szDosGB2312Text);	 break;
	      case TGSJIS:    setdata(szText,szDosSJISText);	 break;
	      case TGKOREAN:  setdata(szText,szDosKoreanText);	 break;
	      default:	      setdata(szText,szDosAsciiText);	 break;
	    }
	}
	return 0;
}
//
//	End of this Program file
//
